package de.intevation.gnv.state.profile.horizontal;

import de.intevation.artifacts.CallContext;
import de.intevation.artifacts.CallMeta;

import de.intevation.gnv.artifacts.ressource.RessourceFactory;

import de.intevation.gnv.geobackend.base.Result;

import de.intevation.gnv.state.StateBase;

import de.intevation.gnv.state.describedata.DefaultKeyValueDescribeData;
import de.intevation.gnv.state.describedata.KeyValueDescibeData;
import de.intevation.gnv.state.describedata.NamedArrayList;
import de.intevation.gnv.state.describedata.NamedCollection;

import de.intevation.gnv.state.exception.StateException;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

/**
 * This states handles coordinate inputs.
 * 
 * @author <a href="mailto:tim.englich@intevation.de">Tim Englich</a>
 */
public class NorthSouthEastWestState extends StateBase {


    /**
     * The UID of this Class
     */
    private static final long serialVersionUID = -7989531326553305293L;

    protected String ipos;
    protected String jpos;

    /**
     * Constructor
     */
    public NorthSouthEastWestState() {
    }


    @Override
    protected List<Object> purifyResult(Collection<Result> result, String uuid) {
        List<Object> describeData = new ArrayList<Object>();

        NamedCollection<KeyValueDescibeData> keyValueDescibeData =
            new NamedArrayList<KeyValueDescibeData>(dataName, 2);

        keyValueDescibeData.setMultiSelect(super.dataMultiSelect);
        keyValueDescibeData.add(new DefaultKeyValueDescribeData(
            "IPOSITION", ipos));
        keyValueDescibeData.add(new DefaultKeyValueDescribeData(
            "JPOSITION", jpos));
        describeData.add(keyValueDescibeData);

        return describeData;
    }


    @Override
    public void initialize(String uuid, CallContext context)
    throws StateException
    {
        CallMeta callMeta        = context.getMeta();
        RessourceFactory factory = RessourceFactory.getInstance();

        // XXX Workarround - we need these strings in purifyResult, but have no
        // CallMeta object there which is necessary to get resources from
        // RessourceFactory. Storing the strings here is not nice, because the
        // Locale object could change!
        ipos = factory.getRessource(
            callMeta.getLanguages(), "iposition", "iposition");
        jpos = factory.getRessource(
            callMeta.getLanguages(), "jposition", "jposition");
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :